@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2002-2006
+ * Copyright (C) 2002-2009
  * Emmanuel Saracco <esaracco@users.labs.libre-entreprise.org>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -520,9 +520,8 @@ void
   GtkWidget *widget = NULL;
 
   widget = WGET ("pd_dynamic_values_time_between");
-  uc_project_set_check_wait ((guint)
-			     gtk_spin_button_get_value (GTK_SPIN_BUTTON
-							(widget)));
+  uc_project_set_check_wait (gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
+							       (widget)));
 }
 
 void
@@ -543,9 +542,8 @@ void
   GtkWidget *widget = NULL;
 
   widget = WGET ("pd_dynamic_values_timeout");
-  uc_project_set_check_timeout ((guint)
-				gtk_spin_button_get_value (GTK_SPIN_BUTTON
-							   (widget)));
+  uc_project_set_check_timeout (gtk_spin_button_get_value_as_int
+				(GTK_SPIN_BUTTON (widget)));
 }
 
 void
